@@ -59,8 +59,8 @@ auth: {
     logout: function(){
         return APIXHRService("POST", API_PATH + "logout")
     },
-    getSAMLRedirectURL : function(tenantId){
-        return APIXHRService("POST", API_PATH + "get-saml-redirect-url", {tenantId: tenantId});
+    getSAMLRedirectURL : function(tenantId, redirectTo){
+        return APIXHRService("POST", API_PATH + "get-saml-redirect-url", {tenantId, redirectTo});
     },
     getOpenIDRedirectURL : function(){
         return APIXHRService("GET", API_PATH + "get-openid-redirect-url", {dssUrl: urlWithProtocolAndHost()});
