@@ -36,7 +36,7 @@
             toggleGroupTileScrollBarDisplay: '&' // ({ $forceShow: boolean, $scrollTopOnHide: boolean }) => void
         },
         templateUrl: '/static/dataiku/js/dashboards/components/dashboard-grid/dashboard-grid.component.html',
-        controller: function(DashboardFilters, $timeout, $rootScope, DashboardUtils, DashboardPageUtils, TileLoadingState, TileLoadingBehavior, $element, $scope, $q, ContextualMenu, TileUtils, LinkedList, DetectUtils, Debounce, WT1) {
+        controller: function(DashboardFilters, $timeout, $rootScope, DashboardUtils, DashboardPageUtils, TileLoadingState, TileLoadingBehavior, $element, $scope, $q, ContextualMenu, TileUtils, LinkedList, DetectUtils, Debounce, WT1, Logger) {
             const ctrl = this;
 
             /*
@@ -293,8 +293,11 @@
 
             ctrl.loadTiles = function(tileLoadingPromiseByTileId) {
                 // Compute how many tiles we can load given the number of already loading tiles
-                const nbLoading = DashboardPageUtils.getNumberOfLoadingTiles(tileLoadingPromiseByTileId, ctrl.hook);
-                const remainingLoadingSlots = nbSimultaneousLoading - nbLoading;
+                const nbLoading = DashboardPageUtils.getNumberOfLoadingTiles(ctrl.hook);
+                if (nbLoading > nbSimultaneousLoading) {
+                    Logger.warn('More tiles than allowed are loading at the same time. There might be an issue.');
+                }
+                const remainingLoadingSlots = Math.max(0, nbSimultaneousLoading - nbLoading);
 
                 // Build the list of tiles that we should load now.
                 const tilesToLoad = DashboardPageUtils.getTilesToLoadOrderedList(tileLoadingPromiseByTileId, ctrl.hook, getTilesById());
