@@ -251,7 +251,7 @@ app.component("apiDeployerMonitoringGovernStatus", {
                 $ctrl.uiState.governStatusLabel = UnifiedMonitoringService.getGovernStatusLabel($ctrl.monitoring.governanceStatus.validationStatus);
                 $ctrl.uiState.governPolicyLabel = UnifiedMonitoringService.getGovernPolicyLabel($ctrl.monitoring.governCheckPolicy);
             }
-            $ctrl.uiState.hasGovernStatus = $ctrl.monitoring.umGovernanceStatus !== "NO_STATUS";
+            $ctrl.uiState.hasGovernStatus = !!$ctrl.monitoring.governanceStatus
         }
     }
 });
@@ -292,7 +292,7 @@ app.component("deployerExternalLinkElement", {
         link: '<'
     },
     template: `
-    <a class="df" href="{{$ctrl.link}}" target="_blank">
+    <a class="link df" href="{{$ctrl.link}}" target="_blank">
         <div show-tooltip-on-text-overflow text-tooltip="$ctrl.text" tooltip-direction="$ctrl.tooltipDirection">
             {{$ctrl.text}}
         </div>
@@ -838,21 +838,52 @@ app.controller('APIDeployerDeploymentCreationModalController', function($scope,
 
 app.controller('APIDeployerDeploymentController',
     function($controller, $scope, $state, WT1, DataikuAPI, Assert, CreateModalFromComponent, apiDeploymentModalDirective, CreateModalFromTemplate, FutureProgressModal,
-             APIDeploymentInfraHelper, Ng2EndpointMetricsRefreshService, StaticApiDeploymentSyncHelper, APIDeployerDeploymentService, ActivityIndicator, STATIC_REFRESH_MODES) {
+             APIDeploymentInfraHelper, Ng2EndpointMetricsRefreshService, StaticApiDeploymentSyncHelper, APIDeployerDeploymentService, ActivityIndicator,
+             STATIC_REFRESH_MODES, apiDeploymentDeletionDeleteServiceModalDirective) {
     $controller('_DeployerDeploymentController', {$scope});
 
     $scope.unsavedTestQueries =  {} // map endpointId -> json query
 
-    $scope.deleteWarning = null;
-
     $scope.uiState = $scope.uiState || {};
 
     $scope.$watch("savedDeploymentSettings", () => {
-        if ($scope.savedDeploymentSettings && $scope.savedDeploymentSettings.enabled && ['STATIC', 'K8S'].includes($scope.savedDeploymentSettings.type)) {
-            const nodeTypes = APIDeploymentInfraHelper.isStaticInfra($scope.savedDeploymentSettings.type) ? "API node(s)" : "Kubernetes node(s)";
-            $scope.deleteWarning = `The deployed API service will not be automatically deleted from the ${nodeTypes}. To delete it, please ensure the deployment has been disabled and updated before deleting the deployment.`;
+        if ($scope.savedDeploymentSettings && ['STATIC', 'K8S'].includes($scope.savedDeploymentSettings.type)) {
+            // The type of a deployment should not change. But we prefer be safe in case this state of things changes
+            if (!$scope.baseDeleteDeployment) {
+                $scope.baseDeleteDeployment = $scope.deleteDeployment;
+            }
+            $scope.deleteDeployment = function() {
+                if (!$scope.lightStatus) {
+                    return;
+                }
+                if ($scope.savedDeploymentSettings.enabled) {
+                    CreateModalFromComponent(apiDeploymentDeletionDeleteServiceModalDirective, null, ['modal-medium']).then((disableFirst) => {
+                        if (disableFirst) {
+                            $scope.deploymentSettings.enabled = false;
+                            $scope.deployerAPIBase.deployments.save($scope.deploymentSettings).success(() => {
+                                $scope.savedDeploymentSettings.enabled = false; // to prevent dirtiness detection
+                                const syncFunc = ($scope.savedDeploymentSettings.type === 'K8S')
+                                    ?
+                                        DataikuAPI.apideployer.deployments.executeSyncDockerBased
+                                    :
+                                        (deploymentId) => DataikuAPI.apideployer.deployments.executeSyncStatic(deploymentId, true);
+                                syncFunc($scope.lightStatus.deploymentBasicInfo.id).success((initialResponse) => {
+                                    FutureProgressModal.show($scope, initialResponse, "Delete deployment").then($scope.reallyDeleteDeployment).error(setErrorInScope.bind($scope));
+                                }).error(setErrorInScope.bind($scope));
+
+                            }).error(setErrorInScope.bind($scope));
+                        } else {
+                            $scope.reallyDeleteDeployment();
+                        }
+                    });
+                } else {
+                    $scope.baseDeleteDeployment();
+                }
+            }
         } else {
-            $scope.deleteWarning = null;
+            if ($scope.baseDeleteDeployment) {
+                $scope.deleteDeployment = $scope.baseDeleteDeployment;
+            }
         }
     });
 
@@ -1098,14 +1129,18 @@ app.controller('APIDeployerDeploymentStatusController', function($scope, $state,
             $scope.heavyStatus = data.data;
             $scope.heavyStatus.endpoints = $scope.heavyStatus.endpoints.map(e => {return {... e, typename: $filter('endpointTypeToName')(e.type)}});
             $scope.deploymentStatus = DeployerDeploymentTileService.getDeploymentHealth($scope.heavyStatus);
-            if (!$scope.heavyStatus || !$scope.heavyStatus.endpoints || !$scope.heavyStatus.endpoints.length) {
+            if (!$scope.heavyStatus) {
                 return;
             }
-            $scope.setCurrentEndpointId(entryEndpointId ? entryEndpointId : $scope.heavyStatus.endpoints[0].id);
-            $scope.uiState.showHealthMessages = !['HEALTHY', 'DISABLED'].includes($scope.heavyStatus.health);
 
             $scope.uiState.expandMessages = $scope.heavyStatus.health === 'UNKNOWN' && $scope.lightStatus.infraBasicInfo.type === 'SAGEMAKER';
 
+            if (!$scope.heavyStatus.endpoints || !$scope.heavyStatus.endpoints.length) {
+                return;
+            }
+
+            $scope.setCurrentEndpointId(entryEndpointId ? entryEndpointId : $scope.heavyStatus.endpoints[0].id);
+
             DataikuAPI.unifiedMonitoring.deployer.apiEndpoints.get(nv.deploymentBasicInfo.id, $scope.currentEndpoint.id).success((monitoring) => {
                 if (monitoring) {
                     if (monitoring.disabledInfra) {
@@ -1132,8 +1167,6 @@ app.controller('APIDeployerDeploymentStatusController', function($scope, $state,
     $scope.$watch("fullCheckReport", function(nv) {
         if(!nv) return;
 
-        $scope.uiState.showHealthMessages = !['HEALTHY', 'DISABLED'].includes(nv.health);
-
         // Trick to avoid retrieving heavy status again to update the status icon
         let heavyStatusCopy = {...$scope.heavyStatus};
         heavyStatusCopy.health = nv.health;
@@ -1673,7 +1706,7 @@ app.controller('APIDeployerDeploymentSettingsController', function($scope, $q, T
     );
 
     const canAccessAuditing = function(infraType) {
-        if (infraType === 'DATABRICKS') {
+        if (infraType === "DATABRICKS") {
             return false;
         }
 
@@ -1681,28 +1714,36 @@ app.controller('APIDeployerDeploymentSettingsController', function($scope, $q, T
             return true;
         }
 
-        return (infraType !== 'STATIC') || $scope.onlyForDataikerAdminWhenInCloud;
+        return (!["STATIC", "K8S"].includes(infraType)) || $scope.onlyForDataikerAdminWhenInCloud;
     };
 
     $scope.$watch("lightStatus", function() {
         if (!$scope.lightStatus) return;
         const infraBasicInfo = $scope.lightStatus.infraBasicInfo;
         const infraType = infraBasicInfo.type;
+        $scope.isDockerBasedInfra = ["SAGEMAKER", "VERTEX_AI", "AZURE_ML", "K8S", "SNOWPARK"].includes(infraType);
         $scope.connectionName = infraBasicInfo.connectionName;
         $scope.infraSupportOpenAPIURI = APIDeployerDeploymentUtils.infraSupportOpenAPIURI(infraType);
         $scope.uiState.showAuditingTab = canAccessAuditing(infraType);
         $scope.fetchAuditLogStorageUrl();
         DataikuAPI.apideployer.infras.getLightStatus(infraBasicInfo.id)
             .success(function(infraStatus) {
-                if (APIDeploymentInfraHelper.isK8SInfra(infraType) && infraStatus.canDeploy) {
-                    $scope.inlineContainerConfig.kubernetesNamespace = infraStatus.infraBasicInfo.k8sNamespace;
-                    $scope.inlineContainerConfig.kubeCtlContext = infraStatus.infraBasicInfo.k8sContext;
-                    $scope.inlineContainerConfig.kubeConfigPath = infraStatus.infraBasicInfo.k8sConfigPath;
-                    $scope.inlineContainerConfig.properties = infraStatus.infraBasicInfo.k8sProperties;
-                    $scope.inlineContainerConfig.baseImage = infraStatus.infraBasicInfo.baseImageTag;
-                    $scope.inlineContainerConfig.repositoryURL = infraStatus.infraBasicInfo.registryHost;
-                    $scope.inlineContainerConfig.prePushMode = infraStatus.infraBasicInfo.prePushMode;
-                    $scope.inlineContainerConfig.prePushScript = infraStatus.infraBasicInfo.prePushScript;
+                if (APIDeploymentInfraHelper.isK8SInfra(infraType)) {
+                    if (infraStatus.canDeploy) {
+                        $scope.inlineContainerConfig.kubernetesNamespace = infraStatus.infraBasicInfo.k8sNamespace;
+                        $scope.inlineContainerConfig.kubeCtlContext = infraStatus.infraBasicInfo.k8sContext;
+                        $scope.inlineContainerConfig.kubeConfigPath = infraStatus.infraBasicInfo.k8sConfigPath;
+                        $scope.inlineContainerConfig.properties = infraStatus.infraBasicInfo.k8sProperties;
+                        $scope.inlineContainerConfig.baseImage = infraStatus.infraBasicInfo.baseImageTag;
+                        $scope.inlineContainerConfig.repositoryURL = infraStatus.infraBasicInfo.registryHost;
+                        $scope.inlineContainerConfig.prePushMode = infraStatus.infraBasicInfo.prePushMode;
+                        $scope.inlineContainerConfig.prePushScript = infraStatus.infraBasicInfo.prePushScript;
+                    } else {
+                        // Copy only the dataiku defined properties triggering the display of some exposition modes
+                        // so that a user with "View" permission on a deployment can properly see related configuration
+                        $scope.inlineContainerConfig.properties = (infraStatus.infraBasicInfo?.k8sProperties || [])
+                            .filter(p => ["cloud.provider", "nginx-ingress.controller"].includes(p.key));
+                    }
                 }
 
                 if (infraType === 'DATABRICKS') {
@@ -1928,6 +1969,17 @@ app.controller('APIDeployerDeploymentsDashboardController', function($scope, $co
         id: hs,
         $selected: false
     }));
+
+    $scope.uiState.query.typeBadgesMap = [
+        '-',
+        'AGENT',
+        'LLM',
+        'ML'
+    ].map(tb => ({
+        id: tb,
+        $selected: false
+    }));
+
     $scope.orderByExpression = ['serviceBasicInfo.id', (deployment) => $filter('deploymentToGenerationList')(deployment.deploymentBasicInfo), '-deploymentBasicInfo.enabled', 'deploymentBasicInfo.id'];
 
     $scope.stillRefreshing = function() {
@@ -1968,12 +2020,20 @@ app.controller('APIDeployerDeploymentsDashboardController', function($scope, $co
     $scope.deploymentIsInUI = function(lightStatus) {
         const selectedServices = $scope.uiState.query.services.filter(service => service.$selected);
         const selectedStatuses = $scope.uiState.query.healthStatusMap.filter(hs => hs.$selected);
+        const selectedTypeBadges = $scope.uiState.query.typeBadgesMap.filter(tb => tb.$selected);
         const deploymentHealthStatus = $scope.heavyStatusPerDeploymentId[lightStatus.deploymentBasicInfo.id];
 
         return filterOnSearchBarQuery(lightStatus) &&
             (!selectedServices.length || selectedServices.find(service => service.serviceBasicInfo.id === lightStatus.deploymentBasicInfo.publishedServiceId)) &&
             (!$scope.uiState.query.tags.length || $scope.uiState.query.tags.find(tag => lightStatus.deploymentBasicInfo.tags.find(deplTag => deplTag === tag))) &&
-            (!selectedStatuses.length || selectedStatuses.find(hs => deploymentHealthStatus && deploymentHealthStatus.health === hs.id || hs.id === 'DISABLED' && !lightStatus.deploymentBasicInfo.enabled));
+            (!selectedStatuses.length || selectedStatuses.find(hs => deploymentHealthStatus && deploymentHealthStatus.health === hs.id || hs.id === 'DISABLED' && !lightStatus.deploymentBasicInfo.enabled)) &&
+            (!selectedTypeBadges.length || selectedTypeBadges.find(tb => {
+                if (tb.id === '-') {
+                    return !lightStatus.deploymentBasicInfo.typeBadges || lightStatus.deploymentBasicInfo.typeBadges.length === 0;
+                } else {
+                    return lightStatus.deploymentBasicInfo.typeBadges.find(deplTb => deplTb === tb.id)
+                }
+            }));
     };
 
     $scope.getFilteredDeploymentCountText = function(deployments) {
@@ -1982,6 +2042,19 @@ app.controller('APIDeployerDeploymentsDashboardController', function($scope, $co
         return (counts.disabled > 0 ? counts.enabled + '/' : '') + counts.total;
     };
 
+    $scope.clearAllAndRefreshFilter = function() {
+        $scope.clearSelectedItems($scope.uiState.query.services);
+        $scope.uiState.query.tags = [];
+        $scope.clearSelectedItems($scope.uiState.query.healthStatusMap);
+        $scope.filterDeployments();
+    }
+
+    $scope.hasSelection = function() {
+        return $scope.uiState.query.tags.length > 0 ||
+            $scope.uiState.query.services.some(elem => elem.$selected) ||
+            $scope.uiState.query.healthStatusMap.some(elem => elem.$selected);
+    }
+
     $scope.$watch('serviceStatusList', function(nv) {
         if (!nv) return;
 
