@@ -91,7 +91,7 @@ app.controller("_AgentSavedModelController", function($scope, $rootScope, $state
 });
 
 app.controller("AgentSavedModelDesignController", function($scope, $rootScope, $state, $stateParams, $controller, ActivityIndicator, CodeBasedEditorUtils,
-                                                           CreateModalFromTemplate, DataikuAPI, PluginConfigUtils, PluginsService, TopNav, AgentDefaultQuickTestQuery) {
+                                                           CreateModalFromTemplate, DataikuAPI, PluginConfigUtils, PluginsService, TopNav) {
     $controller("_AgentSavedModelController", {$scope});
 
     $scope.editorOptions = CodeBasedEditorUtils.editorOptions('text/x-python', $scope, true);
@@ -139,12 +139,6 @@ app.controller("AgentSavedModelDesignController", function($scope, $rootScope, $
             }
         }).error(setErrorInScope.bind($scope));
 
-        if ($scope.currentVersionData && !$scope.currentVersionData.quickTestQuery) {
-            $scope.currentVersionData.quickTestQuery = AgentDefaultQuickTestQuery;
-            $scope.savedModel.inlineVersions[$scope.currentVersionIdx].quickTestQuery = $scope.currentVersionData.quickTestQuery;
-            $scope.save();
-        }
-
         $scope.internalCodeEnvsHRef = function() {
             if ($scope.appConfig.isAutomation) {
                 return $state.href("admin.codeenvs-automation.internal");
@@ -243,7 +237,7 @@ app.controller("AgentVersionHistoryController", function($scope, $stateParams, $
 });
 
 
-app.controller("AgentSavedModelLogsController", function($scope, $stateParams, $controller, DataikuAPI, TopNav) {
+app.controller("AgentSavedModelLogsController", function($scope, $stateParams, $controller, DataikuAPI, Dialogs, TopNav) {
     $controller("_AgentSavedModelController", { $scope });
 
     $scope.listLogs = function() {
@@ -252,6 +246,23 @@ app.controller("AgentSavedModelLogsController", function($scope, $stateParams, $
         }).error(setErrorInScope.bind($scope));
     }
 
+    $scope.clearLogs = function() {
+        const title = 'Confirm logs deletion';
+        const message = 'Are you sure you want to clear the logs for this agent?';
+
+        Dialogs.confirm($scope, title, message).then(() => {
+            DataikuAPI.savedmodels.agents.clearLogs($stateParams.projectKey, $scope.savedModel.id, $scope.currentVersionId)
+                .error(setErrorInScope.bind($scope))
+                .finally($scope.listLogs);
+        });
+    }
+
+    $scope.logDelete = function(projectKey, savedModelId, versionId, logName) {
+        return DataikuAPI.savedmodels.agents.deleteLog(projectKey, savedModelId, versionId, logName)
+                .error(setErrorInScope.bind($scope))
+                .finally($scope.listLogs);
+    }
+
     $scope.logGet = DataikuAPI.savedmodels.agents.getLog;
     $scope.logDownloadURL = function(projectKey, savedModelId, versionId, logName) {
         return "/dip/api/savedmodels/agents/stream-log?projectKey=" + projectKey + "&smId=" + encodeURIComponent(savedModelId) + "&versionId=" + encodeURIComponent(versionId) + "&logName=" + encodeURIComponent(logName);
@@ -417,6 +428,16 @@ app.component('artifactDocument', {
                         $ctrl.imagePaths = $ctrl.part.imageRefs.map(image => image['path']);
                     }
                 }
+                if ($ctrl.part.jsonSnippet) {
+                    try {
+                        $ctrl.parsedJsonSnippet = JSON.parse($ctrl.part.jsonSnippet);
+                    } catch (error) {
+                        $ctrl.parsedJsonSnippet = {
+                            parsingError: "Invalid JSON format.",
+                            originalValue: $ctrl.part.jsonSnippet
+                        };
+                    }
+                }
             }
         };
     },
