@@ -1,6 +1,8 @@
+// @ts-check
 (function() {
     'use strict';
 
+    // @ts-ignore
     angular.module('dataiku.directives.simple_report')
         .factory('ChartFeatures', chartFeatures);
 
@@ -8,6 +10,8 @@
      * ChartFeatures service
      * Defines which UI option is available based on chart type.
      * (!) This service previously was in static/dataiku/js/simple_report/services/chart-features.service.js
+     * @typedef {import("../../../../../../../../server/src/frontend/src/app/features/simple-report/services/chart-features/chart-features.type").ChartFeatureReturnType} ChartFeatureReturnType
+     * @returns {ChartFeatureReturnType}
      */
     function chartFeatures(WebAppsService, ChartStoreFactory, ChartDimension, ChartsStaticData, ChartUADimension, ChartTypeChangeUtils, D3ChartZoomControl, CHART_TYPES, CHART_VARIANTS, CHART_AXIS_TYPES, NumberFormatter, AxisTicksConfigMode, VALUES_DISPLAY_MODES, translate) {
 
@@ -19,13 +23,15 @@
             return chartDef.type === CHART_TYPES.STACKED_COLUMNS && chartDef.variant !== CHART_VARIANTS.stacked100;
         }
 
-        const canSetCustomAxisRange = chartDef => chartDef.variant !== CHART_VARIANTS.binnedXYHexagon;
+        const canSetCustomAxisRange = chartDef => chartDef && chartDef.variant !== CHART_VARIANTS.binnedXYHexagon;
         const axisTicksModes = [
             { label: translate('CHARTS.SETTINGS.FORMAT.AXIS_TICKS.NUMBER', 'Number'), value: AxisTicksConfigMode.NUMBER },
             { label: translate('CHARTS.SETTINGS.FORMAT.AXIS_TICKS.INTERVAL', 'Interval'), value: AxisTicksConfigMode.INTERVAL }
         ];
 
+        /** @type {ChartFeatureReturnType} */
         const svc = {
+
             canDisplayTotalValues,
 
             canExportToExcel: chartDef => {
@@ -97,6 +103,7 @@
             },
 
             canHaveZoomControls: (chartDef, zoomControlInstanceId) => {
+                // @ts-ignore
                 return !_.isNil(chartDef) && !_.isNil(zoomControlInstanceId) && (svc.canHaveEChartsZoomControls(chartDef) || svc.hasScatterZoomControlEnabled(chartDef.type, zoomControlInstanceId) || svc.canHaveMapsZoomControls(chartDef));
             },
 
@@ -175,17 +182,17 @@
                 && chartDef.scatterOptions.regression && chartDef.scatterOptions.regression.show;
             },
 
-            canSelectPivotRowOrColumnDisplayMode: chartDef => chartDef.type === CHART_TYPES.PIVOT_TABLE &&
+            canSelectPivotRowOrColumnDisplayMode: chartDef => chartDef != null && chartDef.type === CHART_TYPES.PIVOT_TABLE &&
                 chartDef.yDimension && chartDef.yDimension.length > 0 && chartDef.xDimension && chartDef.xDimension.length > 0,
 
-            canCustomizePivotFormatting: chartDef => chartDef.type === CHART_TYPES.PIVOT_TABLE &&
+            canCustomizePivotFormatting: chartDef => chartDef != null && chartDef.type === CHART_TYPES.PIVOT_TABLE &&
                 ((chartDef.yDimension && chartDef.yDimension.length > 0) || (chartDef.xDimension && chartDef.xDimension.length > 0))
                 && (chartDef.genericMeasures && chartDef.genericMeasures.length),
 
             canCustomizePivotRowHeaders: chartDef => svc.canCustomizePivotFormatting(chartDef) &&
                 (chartDef.yDimension && chartDef.yDimension.length > 0) || (chartDef.genericMeasures && chartDef.genericMeasures.length > 1),
 
-            isColoredPivotTable: chartDef => chartDef.type === CHART_TYPES.PIVOT_TABLE && (
+            isColoredPivotTable: chartDef => chartDef != null && chartDef.type === CHART_TYPES.PIVOT_TABLE && (
                 chartDef.colorMeasure && chartDef.colorMeasure.length ||
                 chartDef.colorMode === 'COLOR_GROUPS'
             ),
@@ -205,6 +212,7 @@
             ]),
 
             shouldDisplayTooltips: (noTooltips, tooltipOptions, fixed) => {
+                // @ts-ignore
                 const isInADashboard = !_.isNil(noTooltips);
 
                 // If the Show tooltip checkbox is unchecked at chart level, it can still be forced for this chart in a dashboard with the one set at dashboard level
@@ -249,11 +257,19 @@
                 CHART_TYPES.GROUPED_XY
             ]),
 
+            isPivotTableWithNoDimension: (chartDef) => {
+                return chartDef.type === CHART_TYPES.PIVOT_TABLE && chartDef.xDimension.length == 0 && chartDef.yDimension.length == 0;
+            },
+
             canHaveConditionalFormatting: chartType => isChartTypeInList(chartType, [
                 CHART_TYPES.PIVOT_TABLE, CHART_TYPES.KPI
             ]),
 
             hasLogarithmicRegressionWarning: (chartDef) => {
+                if (chartDef == null) {
+                    return false;
+                }
+
                 const areValuesLessOrEqual0 = chartDef.xAxisFormatting && chartDef.xAxisFormatting.customExtent && chartDef.xAxisFormatting.customExtent.$autoExtent && chartDef.xAxisFormatting.customExtent.$autoExtent[0] <= 0;
                 const isAxisMinAbove0 = chartDef.xAxisFormatting && chartDef.xAxisFormatting.customExtent && chartDef.xAxisFormatting.customExtent.manualExtent && chartDef.xAxisFormatting.customExtent.manualExtent[0] > 0;
 
@@ -261,6 +277,10 @@
             },
 
             hasExponentialRegressionWarning: (chartDef, yAxisID = ChartsStaticData.LEFT_AXIS_ID) => {
+                if (chartDef == null) {
+                    return false;
+                }
+
                 const yAxisFormatting = chartDef.yAxesFormatting.find(v => v.id === yAxisID);
                 const areValuesLessOrEqual0 = yAxisFormatting && yAxisFormatting.customExtent && yAxisFormatting.customExtent.$autoExtent && yAxisFormatting.customExtent.$autoExtent[0] <= 0;
                 const isAxisMinAbove0 = yAxisFormatting && yAxisFormatting.customExtent && yAxisFormatting.customExtent.manualExtent && yAxisFormatting.customExtent.manualExtent[0] > 0;
@@ -269,7 +289,7 @@
             },
 
             canEditAxisRange: (chartDef) => {
-                return !(ChartUADimension.areAllNumericalOrDate(chartDef) && chartDef.type === CHART_TYPES.SCATTER
+                return chartDef != null && !(ChartUADimension.areAllNumericalOrDate(chartDef) && chartDef.type === CHART_TYPES.SCATTER
                     && chartDef.scatterOptions && chartDef.scatterOptions.equalScales);
             },
 
@@ -281,6 +301,10 @@
             hasMultipleXDim: chartType => chartType === CHART_TYPES.SCATTER_MULTIPLE_PAIRS,
 
             canSetLogScale: (chartDef, axisName, id) => {
+                if (chartDef == null) {
+                    return false;
+                }
+
                 switch (axisName) {
                     case 'x':
                         if (chartDef.type === CHART_TYPES.SCATTER) {
@@ -508,13 +532,13 @@
             },
 
             hasDefaultEChartsDisplay: chartType => {
-                return [
+                return chartType != null && [
                     CHART_TYPES.PIE
                 ].includes(chartType);
             },
 
             hasEChartsDefinition: chartType => {
-                return [
+                return chartType != null && [
                     CHART_TYPES.GAUGE,
                     CHART_TYPES.PIE,
                     CHART_TYPES.RADAR,
@@ -524,7 +548,7 @@
             },
 
             hasD3Definition: chartType => {
-                return [
+                return chartType != null && [
                     CHART_TYPES.GROUPED_COLUMNS,
                     CHART_TYPES.STACKED_BARS,
                     CHART_TYPES.STACKED_COLUMNS,
@@ -554,7 +578,7 @@
             },
 
             hasBetaBadge: (chartType, isEChartsToggled) => {
-                return svc.hasEChartsDefinition(chartType) && svc.hasD3Definition(chartType) && !svc.hasDefaultEChartsDisplay(chartType) && isEChartsToggled;
+                return svc.hasEChartsDefinition(chartType) && svc.hasD3Definition(chartType) && !svc.hasDefaultEChartsDisplay(chartType) && !!isEChartsToggled;
             },
 
             canDisplayLegend: (chartType) => {
